@@ -3,7 +3,7 @@ package Log::Mini;
 use strict;
 use warnings;
 
-our $VERSION = "0.0.1";
+our $VERSION = "0.0.2";
 
 use Log::Mini::LoggerFILE;
 use Log::Mini::LoggerSTDERR;
@@ -12,6 +12,8 @@ sub new {
     my $class = shift;
     my ( $type, @args ) = @_;
 
+    $type = 'stderr' unless defined $type;
+
     if ( $type eq 'file' ) {
         return Log::Mini::LoggerFILE->new(@args);
     }
@@ -36,9 +38,11 @@ Log::Mini - It's a very simple logger which can log your messages to a file or S
 
     use Log::Mini;
 
-    my $logger = Log::Mini->get_logger(); #STDERR logger used by default
-    $logger->warn('Very important message');
+    my $logger = Log::Mini->get_logger(); #STDERR logger used by default. Error is default log level
+    $logger->error('Error message');
 
+    my $debug_logger = Log::Mini->get_logger('stderr', level => 'debug'); #STDERR logger used by default
+    $debug_logger->error('Error message');
 
     my $file_logger = Log::Mini->get_logger(file => 'log_file.log');
     $file_logger->info('message to log file');
